@@ -37,7 +37,7 @@ settings.register_profile("deterministic", settings(
     derandomize=True,
 ))
 
-if os.environ['DETERMINISTIC_TESTS'].lower() == 'true':
+if os.environ.get('DETERMINISTIC_TESTS', 'false').lower() == 'true':
     settings.load_profile("deterministic")
-elif os.environ['CI'].lower() == 'true':
+elif os.environ.get('CI', 'false').lower() == 'true':
     settings.load_profile("ci")
