@@ -1,6 +1,7 @@
 # -*- coding: utf-8 -*-
 
 import random
+import uuid
 
 import textwrap
 from urllib.parse import quote as urlquote, unquote as urlunquote
@@ -10,8 +11,9 @@ from hypothesis import given
 
 import pytest
 
-import vdirsyncer.exceptions as exceptions
-from vdirsyncer.storage.base import Item, normalize_meta_value
+from vdirsyncer import exceptions
+from vdirsyncer.storage.base import normalize_meta_value
+from vdirsyncer.vobject import Item
 
 from .. import EVENT_TEMPLATE, TASK_TEMPLATE, VCARD_TEMPLATE, \
     assert_item_equals, normalize_item, printable_characters_strategy
@@ -76,7 +78,10 @@ class StorageTests(object):
         items = [get_item() for i in range(1, 10)]
         hrefs = []
         for item in items:
-            hrefs.append(s.upload(item))
+            href, etag = s.upload(item)
+            if etag is None:
+                _, etag = s.get(href)
+            hrefs.append((href, etag))
         hrefs.sort()
         assert hrefs == sorted(s.list())
         for href, etag in hrefs:
@@ -91,6 +96,8 @@ class StorageTests(object):
 
     def test_get_multi_duplicates(self, s, get_item):
         href, etag = s.upload(get_item())
+        if etag is None:
+            _, etag = s.get(href)
         (href2, item, etag2), = s.get_multi([href] * 2)
         assert href2 == href
         assert etag2 == etag
@@ -109,10 +116,14 @@ class StorageTests(object):
     def test_update(self, s, get_item):
         item = get_item()
         href, etag = s.upload(item)
+        if etag is None:
+            _, etag = s.get(href)
         assert_item_equals(s.get(href)[0], item)
 
         new_item = get_item(uid=item.uid)
         new_etag = s.update(href, new_item, etag)
+        if new_etag is None:
+            _, new_etag = s.get(href)
         # See https://github.com/pimutils/vdirsyncer/issues/48
         assert isinstance(new_etag, (bytes, str))
         assert_item_equals(s.get(href)[0], new_item)
@@ -142,6 +153,8 @@ class StorageTests(object):
     def test_list(self, s, get_item):
         assert not list(s.list())
         href, etag = s.upload(get_item())
+        if etag is None:
+            _, etag = s.get(href)
         assert list(s.list()) == [(href, etag)]
 
     def test_has(self, s, get_item):
@@ -153,12 +166,12 @@ class StorageTests(object):
         assert not s.has(href)
 
     def test_update_others_stay_the_same(self, s, get_item):
-        info = dict([
-            s.upload(get_item()),
-            s.upload(get_item()),
-            s.upload(get_item()),
-            s.upload(get_item())
-        ])
+        info = {}
+        for _ in range(4):
+            href, etag = s.upload(get_item())
+            if etag is None:
+                _, etag = s.get(href)
+            info[href] = etag
 
         assert dict(
             (href, etag) for href, item, etag
@@ -187,8 +200,9 @@ class StorageTests(object):
 
     def test_create_collection(self, requires_collections, get_storage_args,
                                get_item):
-        if getattr(self, 'dav_server', '') == 'radicale':
-            pytest.xfail('MKCOL is broken under Radicale 1.x')
+        if getattr(self, 'dav_server', '') in \
+           ('icloud', 'fastmail', 'davical'):
+            pytest.skip('Manual cleanup would be necessary.')
 
         args = get_storage_args(collection=None)
         args['collection'] = 'test'
@@ -197,8 +211,8 @@ class StorageTests(object):
             **self.storage_class.create_collection(**args)
         )
 
-        item = s.upload(get_item())
-        assert item in set(s.list())
+        href = s.upload(get_item())[0]
+        assert href in set(href for href, etag in s.list())
 
     def test_discover_collection_arg(self, requires_collections,
                                      get_storage_args):
@@ -209,6 +223,9 @@ class StorageTests(object):
         assert 'collection argument must not be given' in str(excinfo.value)
 
     def test_collection_arg(self, get_storage_args):
+        if self.storage_class.storage_name.startswith('etesync'):
+            pytest.skip('etesync uses UUIDs.')
+
         if self.supports_collections:
             s = self.storage_class(**get_storage_args(collection='test2'))
             # Can't do stronger assertion because of radicale, which needs a
@@ -222,8 +239,9 @@ class StorageTests(object):
         if s.storage_name == 'filesystem':
             pytest.skip('Behavior depends on the filesystem.')
 
-        s.upload(get_item(uid='A' * 42))
-        s.upload(get_item(uid='a' * 42))
+        uid = str(uuid.uuid4())
+        s.upload(get_item(uid=uid.upper()))
+        s.upload(get_item(uid=uid.lower()))
         items = list(href for href, etag in s.list())
         assert len(items) == 2
         assert len(set(items)) == 2
@@ -231,7 +249,9 @@ class StorageTests(object):
     def test_specialchars(self, monkeypatch, requires_collections,
                           get_storage_args, get_item):
         if getattr(self, 'dav_server', '') == 'radicale':
-            pytest.xfail('Radicale is fundamentally broken.')
+            pytest.skip('Radicale is fundamentally broken.')
+        if getattr(self, 'dav_server', '') in ('icloud', 'fastmail'):
+            pytest.skip('iCloud and FastMail reject this name.')
 
         monkeypatch.setattr('vdirsyncer.utils.generate_href', lambda x: x)
 
@@ -243,18 +263,16 @@ class StorageTests(object):
 
         href, etag = s.upload(item)
         item2, etag2 = s.get(href)
-        assert etag2 == etag
-        assert_item_equals(item2, item)
+        if etag is not None:
+            assert etag2 == etag
+            assert_item_equals(item2, item)
 
-        (href2, etag2), = s.list()
-        assert etag2 == etag
+        (_, etag3), = s.list()
+        assert etag2 == etag3
 
-        # https://github.com/owncloud/contacts/issues/581
-        assert href2.replace('%2B', '%20') == href
-
-        item2, etag2 = s.get(href)
-        assert etag2 == etag
-        assert_item_equals(item2, item)
+        # etesync uses UUIDs for collection names
+        if self.storage_class.storage_name.startswith('etesync'):
+            return
 
         assert collection in urlunquote(s.collection)
         if self.storage_class.storage_name.endswith('dav'):
@@ -296,16 +314,16 @@ class StorageTests(object):
         if item_type != 'VEVENT':
             pytest.skip('This storage instance doesn\'t support iCalendar.')
 
-        uid = u'abc123'
+        uid = str(uuid.uuid4())
         item = Item(textwrap.dedent(u'''
         BEGIN:VCALENDAR
         VERSION:2.0
         BEGIN:VEVENT
-        DTSTART;TZID=Australia/Sydney:20140325T084000
-        DTEND;TZID=Australia/Sydney:20140325T101000
+        DTSTART;TZID=UTC:20140325T084000Z
+        DTEND;TZID=UTC:20140325T101000Z
         DTSTAMP:20140327T060506Z
         UID:{uid}
-        RECURRENCE-ID;TZID=Australia/Sydney:20140325T083000
+        RECURRENCE-ID;TZID=UTC:20140325T083000Z
         CREATED:20131216T033331Z
         DESCRIPTION:
         LAST-MODIFIED:20140327T060215Z
@@ -316,8 +334,8 @@ class StorageTests(object):
         TRANSP:OPAQUE
         END:VEVENT
         BEGIN:VEVENT
-        DTSTART;TZID=Australia/Sydney:20140128T083000
-        DTEND;TZID=Australia/Sydney:20140128T100000
+        DTSTART;TZID=UTC:20140128T083000Z
+        DTEND;TZID=UTC:20140128T100000Z
         RRULE:FREQ=WEEKLY;UNTIL=20141208T213000Z;BYDAY=TU
         DTSTAMP:20140327T060506Z
         UID:{uid}
