@@ -1,5 +1,7 @@
 # -*- coding: utf-8 -*-
 
+import uuid
+
 import os
 
 import pytest
@@ -9,8 +11,8 @@ import requests.exceptions
 
 from tests import assert_item_equals
 
-import vdirsyncer.exceptions as exceptions
-from vdirsyncer.storage.base import Item
+from vdirsyncer import exceptions
+from vdirsyncer.vobject import Item
 
 from .. import StorageTests, get_server_mixin
 
@@ -22,12 +24,12 @@ ServerMixin = get_server_mixin(dav_server)
 class DAVStorageTests(ServerMixin, StorageTests):
     dav_server = dav_server
 
+    @pytest.mark.skipif(dav_server == 'radicale',
+                        reason='Radicale is very tolerant.')
     def test_dav_broken_item(self, s):
         item = Item(u'HAHA:YES')
-        try:
+        with pytest.raises((exceptions.Error, requests.exceptions.HTTPError)):
             s.upload(item)
-        except (exceptions.Error, requests.exceptions.HTTPError):
-            pass
         assert not list(s.list())
 
     def test_dav_empty_get_multi_performance(self, s, monkeypatch):
@@ -44,11 +46,11 @@ class DAVStorageTests(ServerMixin, StorageTests):
 
     def test_dav_unicode_href(self, s, get_item, monkeypatch):
         if self.dav_server == 'radicale':
-            pytest.xfail('Radicale is unable to deal with unicode hrefs')
+            pytest.skip('Radicale is unable to deal with unicode hrefs')
 
         monkeypatch.setattr(s, '_get_href',
                             lambda item: item.ident + s.fileext)
-        item = get_item(uid=u'lolätvdirsynceröü град сатану')
+        item = get_item(uid=u'град сатану' + str(uuid.uuid4()))
         href, etag = s.upload(item)
         item2, etag2 = s.get(href)
         assert_item_equals(item, item2)
