@@ -1,12 +1,4 @@
-
 # -*- coding: utf-8 -*-
-'''
-    tests.storage.test_memory
-    ~~~~~~~~~~~~~~~~~~~~~~~~~
-
-    :copyright: (c) 2014 Markus Unterwaditzer & contributors
-    :license: MIT, see LICENSE for more details.
-'''
 
 import pytest
 
