@@ -558,8 +558,9 @@ class DAVStorage(Storage):
             headers=headers
         )
 
-    def _parse_prop_responses(self, root):
-        hrefs = set()
+    def _parse_prop_responses(self, root, handled_hrefs=None):
+        if handled_hrefs is None:
+            handled_hrefs = set()
         for response in root.iter('{DAV:}response'):
             href = response.find('{DAV:}href')
             if href is None:
@@ -568,7 +569,7 @@ class DAVStorage(Storage):
 
             href = self._normalize_href(href.text)
 
-            if href in hrefs:
+            if href in handled_hrefs:
                 # Servers that send duplicate hrefs:
                 # - Zimbra
                 #   https://github.com/pimutils/vdirsyncer/issues/88
@@ -580,8 +581,8 @@ class DAVStorage(Storage):
 
             props = response.findall('{DAV:}propstat/{DAV:}prop')
             if props is None or not len(props):
-                dav_logger.warning('Skipping {!r}, properties are missing.'
-                                   .format(href))
+                dav_logger.debug('Skipping {!r}, properties are missing.'
+                                 .format(href))
                 continue
             else:
                 props = _merge_xml(props)
@@ -592,8 +593,8 @@ class DAVStorage(Storage):
 
             etag = getattr(props.find('{DAV:}getetag'), 'text', '')
             if not etag:
-                dav_logger.warning('Skipping {!r}, etag property is missing.'
-                                   .format(href))
+                dav_logger.debug('Skipping {!r}, etag property is missing.'
+                                 .format(href))
                 continue
 
             contenttype = getattr(props.find('{DAV:}getcontenttype'),
@@ -604,7 +605,7 @@ class DAVStorage(Storage):
                                          self.item_mimetype))
                 continue
 
-            hrefs.add(href)
+            handled_hrefs.add(href)
             yield href, etag, props
 
     def list(self):
@@ -838,12 +839,14 @@ class CalDAVStorage(DAVStorage):
         # the spec which values from WebDAV are actually allowed.
         headers['Depth'] = '1'
 
+        handled_hrefs = set()
+
         for caldavfilter in caldavfilters:
             xml = data.format(caldavfilter=caldavfilter).encode('utf-8')
             response = self.session.request('REPORT', '', data=xml,
                                             headers=headers)
             root = _parse_xml(response.content)
-            rv = self._parse_prop_responses(root)
+            rv = self._parse_prop_responses(root, handled_hrefs)
             for href, etag, _prop in rv:
                 yield href, etag
 
